
#line 2 "lex.swf5.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer swf5_create_buffer
#define yy_delete_buffer swf5_delete_buffer
#define yy_scan_buffer swf5_scan_buffer
#define yy_scan_string swf5_scan_string
#define yy_scan_bytes swf5_scan_bytes
#define yy_init_buffer swf5_init_buffer
#define yy_flush_buffer swf5_flush_buffer
#define yy_load_buffer_state swf5_load_buffer_state
#define yy_switch_to_buffer swf5_switch_to_buffer
#define yypush_buffer_state swf5push_buffer_state
#define yypop_buffer_state swf5pop_buffer_state
#define yyensure_buffer_stack swf5ensure_buffer_stack
#define yy_flex_debug swf5_flex_debug
#define yyin swf5in
#define yyleng swf5leng
#define yylex swf5lex
#define yylineno swf5lineno
#define yyout swf5out
#define yyrestart swf5restart
#define yytext swf5text
#define yywrap swf5wrap
#define yyalloc swf5alloc
#define yyrealloc swf5realloc
#define yyfree swf5free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define swf5_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer swf5_create_buffer
#endif

#ifdef yy_delete_buffer
#define swf5_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer swf5_delete_buffer
#endif

#ifdef yy_scan_buffer
#define swf5_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer swf5_scan_buffer
#endif

#ifdef yy_scan_string
#define swf5_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string swf5_scan_string
#endif

#ifdef yy_scan_bytes
#define swf5_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes swf5_scan_bytes
#endif

#ifdef yy_init_buffer
#define swf5_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer swf5_init_buffer
#endif

#ifdef yy_flush_buffer
#define swf5_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer swf5_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define swf5_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state swf5_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define swf5_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer swf5_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define swf5push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state swf5push_buffer_state
#endif

#ifdef yypop_buffer_state
#define swf5pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state swf5pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define swf5ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack swf5ensure_buffer_stack
#endif

#ifdef yylex
#define swf5lex_ALREADY_DEFINED
#else
#define yylex swf5lex
#endif

#ifdef yyrestart
#define swf5restart_ALREADY_DEFINED
#else
#define yyrestart swf5restart
#endif

#ifdef yylex_init
#define swf5lex_init_ALREADY_DEFINED
#else
#define yylex_init swf5lex_init
#endif

#ifdef yylex_init_extra
#define swf5lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra swf5lex_init_extra
#endif

#ifdef yylex_destroy
#define swf5lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy swf5lex_destroy
#endif

#ifdef yyget_debug
#define swf5get_debug_ALREADY_DEFINED
#else
#define yyget_debug swf5get_debug
#endif

#ifdef yyset_debug
#define swf5set_debug_ALREADY_DEFINED
#else
#define yyset_debug swf5set_debug
#endif

#ifdef yyget_extra
#define swf5get_extra_ALREADY_DEFINED
#else
#define yyget_extra swf5get_extra
#endif

#ifdef yyset_extra
#define swf5set_extra_ALREADY_DEFINED
#else
#define yyset_extra swf5set_extra
#endif

#ifdef yyget_in
#define swf5get_in_ALREADY_DEFINED
#else
#define yyget_in swf5get_in
#endif

#ifdef yyset_in
#define swf5set_in_ALREADY_DEFINED
#else
#define yyset_in swf5set_in
#endif

#ifdef yyget_out
#define swf5get_out_ALREADY_DEFINED
#else
#define yyget_out swf5get_out
#endif

#ifdef yyset_out
#define swf5set_out_ALREADY_DEFINED
#else
#define yyset_out swf5set_out
#endif

#ifdef yyget_leng
#define swf5get_leng_ALREADY_DEFINED
#else
#define yyget_leng swf5get_leng
#endif

#ifdef yyget_text
#define swf5get_text_ALREADY_DEFINED
#else
#define yyget_text swf5get_text
#endif

#ifdef yyget_lineno
#define swf5get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno swf5get_lineno
#endif

#ifdef yyset_lineno
#define swf5set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno swf5set_lineno
#endif

#ifdef yywrap
#define swf5wrap_ALREADY_DEFINED
#else
#define yywrap swf5wrap
#endif

#ifdef yyalloc
#define swf5alloc_ALREADY_DEFINED
#else
#define yyalloc swf5alloc
#endif

#ifdef yyrealloc
#define swf5realloc_ALREADY_DEFINED
#else
#define yyrealloc swf5realloc
#endif

#ifdef yyfree
#define swf5free_ALREADY_DEFINED
#else
#define yyfree swf5free
#endif

#ifdef yytext
#define swf5text_ALREADY_DEFINED
#else
#define yytext swf5text
#endif

#ifdef yyleng
#define swf5leng_ALREADY_DEFINED
#else
#define yyleng swf5leng
#endif

#ifdef yyin
#define swf5in_ALREADY_DEFINED
#else
#define yyin swf5in
#endif

#ifdef yyout
#define swf5out_ALREADY_DEFINED
#else
#define yyout swf5out
#endif

#ifdef yy_flex_debug
#define swf5_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug swf5_flex_debug
#endif

#ifdef yylineno
#define swf5lineno_ALREADY_DEFINED
#else
#define yylineno swf5lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 226
#define YY_END_OF_BUFFER 227
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1042] =
    {   0,
        5,    5,    5,    5,    5,    5,    5,    5,  227,  225,
      179,  224,  225,  212,  225,  172,  211,  206,  225,  213,
      214,  209,  204,  219,  205,  220,  210,    3,    3,  222,
      202,  200,  203,  201,  221,  172,  215,  216,  208,  172,
      172,  172,  172,  217,  207,  218,  223,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  212,  203,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  224,  185,    0,  175,  173,    0,  172,

      186,  192,    0,  176,  174,    0,  188,  180,  190,  181,
      191,  177,  178,  189,    4,    2,    3,    0,    0,  194,
      182,  184,  183,  195,    0,    5,  172,  172,  172,  172,
      172,  193,  187,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  107,  172,  172,    0,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      185,  184,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,   74,   75,  172,  172,  172,
      172,  172,  172,  172,   22,  172,  172,  172,  172,  172,

      172,  172,  172,  172,   20,   19,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,   19,  172,
      172,  172,    4,    0,    5,    1,  197,  198,  196,  172,
      172,  172,  172,  172,  110,  106,  172,  172,  172,  117,
      172,  172,   97,  157,  172,  172,  172,  172,  156,  172,
      116,  172,  172,  172,  172,  172,  172,  172,  172,  172,
       96,  136,  172,   99,  172,  172,  167,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  108,   43,   42,  172,  172,  172,  172,  172,  172,

      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,   30,  172,  172,  172,  172,   51,
      172,  172,  172,  172,  172,  172,  172,  172,  172,   18,
      172,  172,  172,  172,   49,  172,  172,   24,  172,   50,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,   38,   23,  172,
      172,  172,    0,    4,  199,  172,    8,    6,  172,  172,
      172,  172,  166,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,

      172,  155,  100,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,   98,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,   89,  172,  172,  172,  172,
      172,  172,  172,   60,   16,  172,  172,  172,  172,  172,
      172,  172,   14,   31,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,   56,  172,  172,  172,  172,
      172,  172,  172,  172,  172,   57,  172,  172,  172,   28,
      172,  172,  172,  172,   29,    7,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,

      172,  172,  172,  172,  172,  172,  151,  172,  150,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  168,  172,  172,  172,
      172,  172,  172,  172,  172,   87,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,   11,   39,   34,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,   40,  172,   33,   21,   10,  172,  152,  172,  172,

      169,  131,  172,  172,  114,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  109,  172,  111,
      172,  172,  172,  172,  128,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,   80,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,   82,  172,
      172,  172,  172,   47,  172,  172,   25,  172,  172,  172,
      172,  172,  172,   52,  172,  172,   46,  172,  172,  172,
      172,  172,   36,   44,  172,   27,  172,  172,  172,  172,
      172,   48,   15,  172,  172,  172,  172,  172,  172,  172,

      170,  172,  172,  158,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,   83,  172,  172,  172,  172,
       85,  172,  172,   94,   76,   95,   77,  172,   17,  172,
       35,   41,  172,  172,  172,   53,  172,  172,  172,  172,
      172,  172,   37,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  112,  172,  172,  148,  172,

      130,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  146,  137,  172,  172,
      129,  172,  172,  159,  160,  172,  172,  172,  172,  172,
      172,   93,  172,  172,  172,   81,   12,  172,   13,  172,
       45,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,   71,  172,  172,  172,    9,  172,  172,  172,
      172,  172,  118,  172,  122,  172,  172,  172,  121,  172,
      172,  135,  172,  115,  172,  105,  104,  132,  172,  172,
      123,  172,  172,  172,  172,  124,  172,  145,  172,  172,
      139,  171,  172,  127,  172,  172,  172,  172,  172,   84,

      172,  172,  172,  172,  172,  172,  172,   65,  172,   54,
       55,  172,  172,   63,   70,  172,  172,  172,  172,  172,
      172,  103,  172,  119,  165,  172,  172,  164,  120,  134,
      172,  172,  172,  172,  172,  172,  172,  172,  125,  172,
      172,  161,  172,  172,   91,  172,  172,  172,  172,  172,
      172,  172,  172,   32,  172,  172,  172,  172,   59,   26,
      172,  172,  172,  172,  172,  140,  142,  149,  113,  133,
      172,  141,  101,  172,  143,  126,  172,  172,  172,   88,
      172,  172,  172,  172,  172,   73,   61,   62,  172,  172,
      172,   72,  172,  153,  154,  102,  172,  172,  172,  138,

      172,  172,  172,   90,  172,   79,  172,   67,  172,  172,
      172,  172,  172,  144,  172,   78,   86,   92,  172,   64,
      172,   58,  172,  172,  147,  172,  172,  172,  172,  163,
      172,  172,   69,  172,  172,   66,  172,  172,  162,   68,
        0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   23,   23,   24,   25,   26,
       27,   28,   29,    1,   30,   31,   32,   33,   34,   35,
        7,    7,    7,    7,    7,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   45,   46,    7,    7,    7,    7,
       47,   48,   49,   50,   51,    1,   52,   53,   54,   55,

       56,   57,   58,   59,   60,   61,   62,   63,   64,   65,
       66,   67,   68,   69,   70,   71,   72,   73,   74,   75,
       76,    7,   77,   78,   79,   80,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[81] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    1,    1,    1,    1,    1,    1,    3,
        3,    3,    3,    3,    3,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    1,    1,    1,    1,
        2,    3,    3,    3,    3,    3,    3,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[1046] =
    {   0,
        0,    0,   29,    0,  100,    0,   52,   74, 1244, 1245,
     1245, 1245, 1240, 1215,   85,    0, 1245,   81,  128, 1245,
     1245, 1214,   87, 1245,   93, 1245,  159,  161,  168, 1245,
     1245,  109, 1213,  119, 1245,  178, 1245, 1245, 1245, 1187,
     1166,   73, 1172, 1245,   70, 1245, 1245,   61, 1167, 1183,
      147,  190,   98, 1178,   97,  149,   58,  160,  145,  155,
      140,  166,  176, 1181, 1166, 1204, 1203,  214, 1159, 1159,
      187,  175,  240,  239,  164,  178,  167,  103, 1158,  209,
      192,  221,  248, 1174,  215,  246,  201,  237,  162,  232,
     1169, 1150,  264, 1245, 1245,  315,  316, 1245, 1220,    0,

     1245, 1245,  317,  322, 1245, 1219, 1245, 1245, 1245, 1245,
     1245, 1245, 1245, 1245,  315,  322,  338,  360,    0, 1194,
     1245, 1245, 1245,  269,  331,  365, 1157, 1156, 1146, 1150,
     1161, 1245, 1245, 1160, 1159, 1161,  299,  312, 1139, 1144,
      274, 1138, 1138, 1154, 1136, 1139,  210, 1135, 1146,  335,
     1148, 1139, 1127, 1129, 1144,    0,  261, 1128,  387, 1133,
     1125, 1135,  345, 1141,  316, 1124,  325,  177, 1123, 1122,
     1163, 1162, 1125, 1115, 1117,  327,  220, 1133, 1112, 1117,
     1116,  127, 1112, 1120, 1119,  348,  349, 1114, 1121,  329,
     1107, 1123, 1109,  358,    0, 1106, 1102, 1119, 1099, 1104,

     1099, 1102, 1095, 1094,    0,  277, 1099, 1111,  328, 1107,
     1109,  250, 1107, 1094,  352, 1087,  325, 1104, 1096, 1086,
      357, 1096,  352, 1084, 1092, 1080,  359, 1085, 1079, 1074,
     1087, 1075,  412,  422,  428,    0, 1245, 1245, 1118, 1074,
     1080, 1086, 1085, 1084,    0,    0, 1074, 1075, 1066,    0,
     1080, 1075, 1071,    0, 1069, 1080, 1075, 1064,  388, 1066,
        0, 1057, 1057, 1066, 1066, 1068, 1054, 1050, 1049, 1049,
      401,    0,  406,    0, 1048, 1059,  451, 1051,  411, 1059,
     1046, 1047, 1053,  369, 1045, 1081, 1052, 1037, 1037, 1053,
     1050,    0, 1245, 1245, 1038, 1035, 1037, 1048, 1049, 1040,

     1041, 1034, 1045, 1025, 1023, 1025, 1022, 1029, 1021, 1035,
     1023, 1034, 1021, 1032,    0, 1033, 1021, 1027, 1028,    0,
     1011,  366, 1028, 1023, 1015, 1021, 1013, 1019, 1022,    0,
     1019,  441, 1006, 1000,    0, 1012, 1014,    0,  997,    0,
      991,  993,  992, 1001, 1008,  996,  989,  286,  991,  992,
      988,  986,  998,  985,  988,  995,  998,    0,    0,  988,
      991,  978,  468,  473, 1245,  992,    0,    0,  388,  990,
      992,  399,    0,  974,  989,  983,  986,  978,  975,  975,
      982,  968,  984,  979,  431,  963,  979,  963,  966,  975,
      976,  965,  967,  971,  957,  968,  967,  969,  966,  952,

      963,    0,    0,  945,  961,  947,  959,  962,  961,  941,
      940,  955,  944,  937,  938,    0,  952,  949,  940,  934,
      946,  933,  941,  930,  931,  925,  932,  937,  935,  937,
      929,  939,  925,  931,  936,    0,  927,  915,  913,  932,
      911,  930,  919,    0,    0,  921,  909,  926,  917,  904,
      904,  914,    0,    0,  908,  909,  900,  901,  909,  434,
      938,  915,  895,  461,  930,    0,  929,  911,  902,  895,
      887,  890,  889,  905,  885,  466,  884,  900,  897,    0,
      878,  888,  894,  893,    0,    0,  891,  887,  887,  873,
      888,  887,  886,  887,  871,  869,  883,  873,  872,  869,

      865,  869,  863,  878,  871,  877,    0,  870,    0,  857,
      860,  858,  869,  851,  852,  850,  859,  864,  846,  847,
      860,  851,  848,  855,  843,  842,  397,  855,  840,  850,
      838,  854,  834,  833,  850,  842,    0,  829,  848,  843,
      827,  827,  840,  836,  826,    0,  833,  821,  836,  834,
      826,  835,  828,  816,  822,  814,  820,    0,    0,    0,
      811,  816,  817,  823,  824,  822,  813,  815,  808,  809,
      441,  807,  806,  811,  803,  816,  798,  797,  794,  810,
      799,  806,  796,  794,  790,  825,  788,  790,  786,  795,
      782,    0,  796,    0,    0,    0,  786,  448,  785,  778,

      827,    0,  795,  794,    0,  775,  792,  790,  775,  781,
      784,  770,  777,  785,  773,  764,  763,    0,  770,    0,
      780,  761,  771,  773,    0,  776,  757,  762,  772,  757,
      763,  764,  761,  764,  759,  749,  765,  449,  756,  761,
      754,  746,  756,  746,  758,    0,  744,  756,  738,  736,
      734,  732,  732,  742,  748,  729,  742,  735,    0,  741,
      740,  739,  738,    0,  721,  721,    0,  739,  720,  713,
      722,  720,  730,  765,  729,  729,    0,  709,  712,  728,
      727,  722,    0,    0,  740,    0,  709,  717,  705,  721,
      700,    0,    0,  731,  729,  713,  705,  710,  712,  706,

        0,  693,  692,    0,  697,  705,  704,  707,  693,  705,
      700,  690,  449,  695,  684,  676,  688,  679,  683,  694,
      684,  675,   47,  195,  252,  297,  366,  373,  402,  421,
      450,  448,  442,  455,  449,  445,  451,  466,  450,  462,
      458,  451,  454,  468,  462,    0,  474,  451,  462,  457,
        0,  461,  475,    0,    0,    0,    0,  476,    0,  462,
        0,    0,  469,  479,  467,    0,  497,  482,  479,  481,
      478,  479,    0,  478,  489,  490,  495,  490,  484,  498,
      479,  497,  479,  483,  484,  490,  501,  502,  504,  491,
      492,  509,  492,  488,  511,    0,  501,  498,    0,  508,

        0,  499,  511,  516,  501,  503,  515,  502,  507,  508,
      507,  508,  527,  510,  523,  525,    0,    0,  519,  527,
        0,  521,  516,    0,    0,  518,  533,  533,  538,  527,
      531,    0,  530,  539,  545,    0,    0,  542,    0,  530,
        0,  537,  530,  563,  547,  552,  549,  550,  534,  539,
      538,  552,    0,  556,  541,  561,    0,  562,  546,  556,
      562,  554,  598,  599,    0,  550,  559,  553,    0,  553,
      570,    0,  561,    0,  575,    0,    0,    0,  576,  570,
        0,  560,  576,  577,  571,    0,  564,    0,  578,  567,
        0,    0,  579,    0,  570,  584,  570,  590,  583,    0,

      573,  581,  609,  576,  596,  583,  593,  613,  599,    0,
        0,  593,  583,    0,    0,  585,  597,  594,  582,  587,
      594,    0,  595,    0,    0,  586,  607,    0,    0,    0,
      606,  600,  601,  611,  592,  600,  595,  615,  651,  602,
      603,    0,  623,  605,    0,  622,  607,  619,  624,  615,
      606,  607,  617,    0,  613,  623,  631,  612,    0,    0,
      629,  620,  635,  627,  620,    0,    0,    0,    0,    0,
      640,    0,    0,  628,    0,    0,  637,  638,  634,    0,
      643,  624,  637,  632,  630,    0,    0,    0,  640,  649,
      674,    0,  636,    0,    0,    0,  648,  646,  641,    0,

      659,  656,  658,    0,  658,    0,  655,    0,  646,  654,
      642,  663,  660,    0,  656,    0,    0,    0,  666,  685,
      664,    0,  671,  659,    0,  695,  656,  662,  667,    0,
      668,  668,    0,  673,  674,    0,  668,  669,    0,    0,
     1245,  736,  738,  741,  742
    } ;

static const flex_int16_t yy_def[1046] =
    {   0,
     1041,    1,    1,    3,    1,    5,    5,    5, 1041, 1041,
     1041, 1041, 1041, 1041, 1042, 1043, 1041, 1041, 1044, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1043, 1041, 1041, 1041, 1043,
     1043, 1043, 1043, 1041, 1041, 1041, 1041, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1041, 1041, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1041, 1041, 1042, 1042, 1041, 1042, 1043,

     1041, 1041, 1044, 1044, 1041, 1044, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1045, 1041,
     1041, 1041, 1041, 1041, 1041, 1043, 1043, 1043, 1043, 1043,
     1043, 1041, 1041, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1041, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1041, 1041, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1041, 1041, 1041, 1045, 1041, 1041, 1041, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1041, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1041, 1041, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1041, 1041, 1041, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,

     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
     1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043, 1043,
        0, 1041, 1041, 1041, 1041
    } ;

static const flex_int16_t yy_nxt[1326] =
    {   0,
       10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
       20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
       29,   29,   29,   30,   31,   32,   33,   34,   35,   16,
       16,   16,   16,   36,   16,   16,   16,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   37,   10,   38,   39,
       16,   16,   16,   16,   16,   36,   40,   16,   16,   16,
       16,   16,   16,   16,   41,   16,   16,   16,   16,   16,
       42,   43,   16,   16,   16,   16,   44,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   97,   55,  101,
       98,   56,   57,   58,   59,   60,  132,   61,   62,   63,

      108,   64,   16,   65,   66,   86,   87,  102,  110,   16,
      150,   88,  808,  109,   16,  134,   89,   16,   90,  111,
       91,   92,   93,  151,   16,  135,   67,   86,   87,  152,
      104,   16,   99,   88,  120,  121,   16,  105,   89,   16,
       90,  129,   91,   92,   93,  123,  124,  133,  130,  127,
       68,   69,   70,   71,   72,   73,   74,   75,  209,   76,
      146,  147,   77,  159,   78,   79,   80,  144,   81,   82,
       83,  112,   84,   85,  128,  106,  113,  115,  306,  116,
      116,  116,  116,  117,  115,  114,  117,  117,  117,  117,
      117,  125,  307,  125,  118,  160,  126,  126,  126,  126,

      126,  118,  138,  125,  148,  125,  139,  155,  126,  126,
      126,  126,  126,  156,  149,  153,  118,  230,  140,  203,
      157,  161,  207,  118,  162,  154,  158,  166,  290,  204,
      194,  128,  208,  128,  205,  119,  163,  164,  190,  165,
      195,  167,  206,  214,  168,  191,  196,  215,  242,  192,
      809,  130,  193,  125,  141,  125,  194,  142,  126,  126,
      126,  126,  126,  261,  143,  173,  195,  174,  175,  262,
      176,  211,  177,  225,  226,  300,  216,  212,  178,  301,
      213,  179,  180,  181,  182,  183,  184,  185,  186,  187,
      127,  217,  218,  205,  219,  238,  239,  227,  200,  220,

      231,  229,  197,  213,  201,  342,  221,  810,  192,  343,
      202,  228,  198,  222,  199,  220,  223,   97,   97,  104,
       98,   98,  221,  130,  104,  473,  105,  274,  254,  474,
      275,  105,  223,  233,  233,  233,  233,  233,  115,  130,
      116,  116,  116,  116,  117,  255,  334,  335,  234,  235,
      235,  235,  235,  235,  115,  118,  117,  117,  117,  117,
      117,  248,   99,   99,  106,  250,  811,  285,  249,  106,
      234,  118,  286,  125,  251,  125,  349,  118,  235,  235,
      235,  235,  235,  126,  126,  126,  126,  126,  265,  288,
      350,  317,  298,  118,  289,  299,  281,  266,  318,  319,

      267,  338,  339,  357,  268,  277,  277,  277,  277,  277,
      282,  311,  313,  283,  323,  346,  354,  312,  314,  448,
      324,  812,  347,  242,  813,  355,  487,  358,  318,  319,
      233,  233,  233,  233,  233,  363,  449,  363,  414,  415,
      364,  364,  364,  364,  364,  234,  235,  235,  235,  235,
      235,  381,  394,  487,  382,  490,  395,  399,  814,  634,
      383,  400,  491,  396,  397,  635,  398,  234,  401,  277,
      277,  277,  277,  277,  405,  571,  674,  406,  815,  407,
      458,  408,  503,  409,  459,  460,  364,  364,  364,  364,
      364,  364,  364,  364,  364,  364,  504,  575,  587,  697,

      797,  816,  571,  674,  733,  817,  576,  698,  588,  818,
      819,  734,  460,  820,  798,  821,  822,  823,  824,  825,
      826,  827,  828,  829,  830,  831,  832,  833,  834,  835,
      836,  837,  838,  839,  840,  841,  842,  844,  845,  843,
      846,  847,  848,  849,  850,  851,  852,  853,  854,  855,
      856,  857,  858,  859,  860,  861,  862,  863,  864,  865,
      866,  867,  868,  869,  870,  871,  872,  873,  874,  875,
      876,  877,  878,  879,  880,  881,  882,  883,  884,  885,
      886,  887,  888,  889,  891,  892,  893,  894,  890,  895,
      896,  897,  898,  899,  900,  901,  902,  903,  904,  905,

      906,  907,  908,  909,  910,  911,  912,  913,  914,  915,
      916,  917,  918,  919,  920,  921,  922,  923,  924,  925,
      926,  927,  928,  929,  930,  931,  932,  933,  907,  934,
      935,  936,  937,  938,  939,  940,  941,  942,  943,  944,
      945,  946,  947,  948,  949,  950,  951,  952,  953,  954,
      955,  956,  957,  958,  959,  960,  961,  962,  963,  964,
      965,  966,  967,  968,  969,  970,  971,  972,  973,  974,
      975,  976,  977,  978,  979,  980,  981,  982,  983,  984,
      985,  986,  987,  988,  989,  990,  991,  992,  993,  994,
      995,  996,  997,  998,  999, 1000, 1001, 1002, 1003, 1004,

     1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014,
     1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024,
     1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034,
     1035, 1036, 1037, 1038, 1039, 1040,   96,   96,   96,  100,
      100,  103,  103,  103,  236,  807,  806,  805,  804,  803,
      802,  801,  800,  799,  796,  795,  794,  793,  792,  791,
      790,  789,  788,  787,  786,  785,  784,  783,  782,  781,
      780,  779,  778,  777,  776,  775,  774,  773,  772,  771,
      770,  769,  768,  767,  766,  765,  764,  763,  762,  761,
      760,  759,  758,  757,  756,  755,  754,  753,  752,  751,

      750,  749,  748,  747,  746,  745,  744,  743,  742,  741,
      740,  739,  738,  737,  736,  735,  732,  731,  730,  729,
      728,  727,  726,  725,  724,  723,  722,  721,  720,  719,
      718,  717,  716,  715,  714,  713,  712,  711,  710,  709,
      708,  707,  706,  705,  704,  703,  702,  701,  700,  699,
      696,  695,  694,  693,  692,  691,  690,  689,  688,  687,
      686,  685,  684,  683,  682,  681,  680,  679,  678,  677,
      676,  675,  673,  672,  671,  670,  669,  668,  667,  666,
      665,  664,  663,  662,  661,  660,  659,  658,  657,  656,
      655,  654,  653,  652,  651,  650,  649,  648,  647,  646,

      645,  644,  643,  642,  641,  640,  639,  638,  637,  636,
      633,  632,  631,  630,  629,  628,  627,  626,  625,  624,
      623,  622,  621,  620,  619,  618,  617,  616,  615,  614,
      613,  612,  611,  610,  609,  608,  607,  606,  605,  604,
      603,  602,  601,  600,  599,  598,  597,  596,  595,  594,
      593,  592,  591,  590,  589,  586,  585,  584,  583,  582,
      581,  580,  579,  578,  577,  574,  573,  572,  570,  569,
      568,  567,  566,  565,  564,  563,  562,  561,  560,  559,
      558,  557,  556,  555,  554,  553,  552,  551,  550,  549,
      548,  547,  546,  545,  544,  543,  542,  541,  540,  539,

      538,  537,  536,  535,  534,  533,  532,  531,  530,  529,
      528,  527,  526,  525,  524,  523,  522,  521,  520,  519,
      518,  517,  516,  515,  514,  513,  512,  511,  510,  509,
      508,  507,  506,  505,  502,  501,  500,  499,  498,  497,
      496,  495,  494,  493,  492,  489,  488,  486,  449,  485,
      484,  483,  482,  481,  480,  479,  478,  477,  476,  475,
      472,  471,  470,  469,  468,  467,  466,  465,  464,  463,
      462,  461,  457,  456,  455,  454,  453,  452,  451,  450,
      447,  446,  445,  444,  443,  442,  441,  440,  439,  438,
      437,  436,  435,  434,  433,  432,  431,  430,  429,  428,

      427,  426,  425,  424,  423,  422,  421,  420,  419,  418,
      417,  416,  413,  412,  411,  410,  404,  403,  402,  393,
      392,  391,  390,  389,  388,  387,  386,  385,  384,  380,
      379,  378,  377,  376,  375,  374,  373,  372,  371,  370,
      369,  368,  367,  366,  365,  347,  343,  338,  334,  362,
      361,  360,  359,  356,  353,  352,  351,  348,  345,  344,
      341,  340,  337,  336,  333,  332,  331,  330,  329,  328,
      327,  326,  325,  322,  321,  320,  316,  315,  310,  309,
      308,  305,  304,  303,  302,  297,  296,  295,  294,  293,
      292,  291,  287,  284,  280,  279,  278,  276,  273,  272,

      271,  270,  269,  264,  263,  260,  259,  258,  257,  256,
      253,  252,  247,  246,  245,  244,  243,  242,  241,  240,
      237, 1041, 1041,  219,  232,  224,  210,  189,  188,  172,
      171,  170,  169,  145,  137,  136,  131,  128,  127,  122,
      107,   95,   94, 1041,    9, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,

     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041
    } ;

static const flex_int16_t yy_chk[1326] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        3,    3,    3,    3,    3,    3,    3,   15,    3,   18,
       15,    3,    3,    3,    3,    3,   45,    3,    3,    3,

       23,    3,    7,    3,    5,    7,    7,   18,   25,    7,
       57,    7,  723,   23,    7,   48,    7,    7,    7,   25,
        7,    7,    7,   57,    8,   48,    5,    8,    8,   57,
       19,    8,   15,    8,   32,   32,    8,   19,    8,    8,
        8,   42,    8,    8,    8,   34,   34,   45,   42,   53,
        5,    5,    5,    5,    5,    5,    5,    5,   78,    5,
       55,   55,    5,   61,    5,    5,    5,   53,    5,    5,
        5,   27,    5,    5,   78,   19,   27,   28,  182,   28,
       28,   28,   28,   28,   29,   27,   29,   29,   29,   29,
       29,   36,  182,   36,   28,   61,   36,   36,   36,   36,

       36,   29,   51,   52,   56,   52,   51,   59,   52,   52,
       52,   52,   52,   59,   56,   58,   28,   89,   51,   75,
       60,   62,   77,   29,   62,   58,   60,   63,  168,   75,
       72,   58,   77,   89,   76,   28,   62,   62,   71,   62,
       72,   63,   76,   81,   63,   71,   72,   81,  168,   71,
      724,   63,   71,   73,   52,   73,   87,   52,   73,   73,
       73,   73,   73,  147,   52,   68,   87,   68,   68,  147,
       68,   80,   68,   85,   85,  177,   82,   80,   68,  177,
       80,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       74,   82,   82,   88,   82,  124,  124,   86,   74,   83,

       90,   88,   73,   90,   74,  212,   83,  725,   86,  212,
       74,   86,   73,   83,   73,   93,   83,   96,   97,  103,
       96,   97,   93,   83,  104,  348,  103,  157,  141,  348,
      157,  104,   93,  115,  115,  115,  115,  115,  116,   93,
      116,  116,  116,  116,  116,  141,  206,  206,  115,  125,
      125,  125,  125,  125,  117,  116,  117,  117,  117,  117,
      117,  137,   96,   97,  103,  138,  726,  165,  137,  104,
      115,  117,  165,  118,  138,  118,  217,  116,  118,  118,
      118,  118,  118,  126,  126,  126,  126,  126,  150,  167,
      217,  190,  176,  117,  167,  176,  163,  150,  190,  190,

      150,  209,  209,  223,  150,  159,  159,  159,  159,  159,
      163,  186,  187,  163,  194,  215,  221,  186,  187,  322,
      194,  727,  215,  223,  728,  221,  369,  223,  227,  227,
      233,  233,  233,  233,  233,  234,  322,  234,  284,  284,
      234,  234,  234,  234,  234,  233,  235,  235,  235,  235,
      235,  259,  271,  369,  259,  372,  271,  273,  729,  527,
      259,  273,  372,  271,  271,  527,  271,  233,  273,  277,
      277,  277,  277,  277,  279,  460,  571,  279,  730,  279,
      332,  279,  385,  279,  332,  332,  363,  363,  363,  363,
      363,  364,  364,  364,  364,  364,  385,  464,  476,  598,

      713,  731,  460,  571,  638,  732,  464,  598,  476,  733,
      734,  638,  332,  735,  713,  736,  737,  738,  739,  740,
      741,  742,  743,  744,  745,  747,  748,  749,  750,  752,
      753,  758,  760,  763,  764,  765,  767,  768,  769,  767,
      770,  771,  772,  774,  775,  776,  777,  778,  779,  780,
      781,  782,  783,  784,  785,  786,  787,  788,  789,  790,
      791,  792,  793,  794,  795,  797,  798,  800,  802,  803,
      804,  805,  806,  807,  808,  809,  810,  811,  812,  813,
      814,  815,  816,  819,  820,  822,  823,  826,  819,  827,
      828,  829,  830,  831,  833,  834,  835,  838,  840,  842,

      843,  844,  845,  846,  847,  848,  849,  850,  851,  852,
      854,  855,  856,  858,  859,  860,  861,  862,  863,  864,
      866,  867,  868,  870,  871,  873,  875,  879,  844,  880,
      882,  883,  884,  885,  887,  889,  890,  893,  895,  896,
      897,  898,  899,  901,  902,  903,  904,  905,  906,  907,
      908,  909,  912,  913,  916,  917,  918,  919,  920,  921,
      923,  926,  927,  931,  932,  933,  934,  935,  936,  937,
      938,  939,  940,  941,  943,  944,  946,  947,  948,  949,
      950,  951,  952,  953,  955,  956,  957,  958,  961,  962,
      963,  964,  965,  971,  974,  977,  978,  979,  981,  982,

      983,  984,  985,  989,  990,  991,  993,  997,  998,  999,
     1001, 1002, 1003, 1005, 1007, 1009, 1010, 1011, 1012, 1013,
     1015, 1019, 1020, 1021, 1023, 1024, 1026, 1027, 1028, 1029,
     1031, 1032, 1034, 1035, 1037, 1038, 1042, 1042, 1042, 1043,
     1043, 1044, 1044, 1044, 1045,  722,  721,  720,  719,  718,
      717,  716,  715,  714,  712,  711,  710,  709,  708,  707,
      706,  705,  703,  702,  700,  699,  698,  697,  696,  695,
      694,  691,  690,  689,  688,  687,  685,  682,  681,  680,
      679,  678,  676,  675,  674,  673,  672,  671,  670,  669,
      668,  666,  665,  663,  662,  661,  660,  658,  657,  656,

      655,  654,  653,  652,  651,  650,  649,  648,  647,  645,
      644,  643,  642,  641,  640,  639,  637,  636,  635,  634,
      633,  632,  631,  630,  629,  628,  627,  626,  624,  623,
      622,  621,  619,  617,  616,  615,  614,  613,  612,  611,
      610,  609,  608,  607,  606,  604,  603,  601,  600,  599,
      597,  593,  591,  590,  589,  588,  587,  586,  585,  584,
      583,  582,  581,  580,  579,  578,  577,  576,  575,  574,
      573,  572,  570,  569,  568,  567,  566,  565,  564,  563,
      562,  561,  557,  556,  555,  554,  553,  552,  551,  550,
      549,  548,  547,  545,  544,  543,  542,  541,  540,  539,

      538,  536,  535,  534,  533,  532,  531,  530,  529,  528,
      526,  525,  524,  523,  522,  521,  520,  519,  518,  517,
      516,  515,  514,  513,  512,  511,  510,  508,  506,  505,
      504,  503,  502,  501,  500,  499,  498,  497,  496,  495,
      494,  493,  492,  491,  490,  489,  488,  487,  484,  483,
      482,  481,  479,  478,  477,  475,  474,  473,  472,  471,
      470,  469,  468,  467,  465,  463,  462,  461,  459,  458,
      457,  456,  455,  452,  451,  450,  449,  448,  447,  446,
      443,  442,  441,  440,  439,  438,  437,  435,  434,  433,
      432,  431,  430,  429,  428,  427,  426,  425,  424,  423,

      422,  421,  420,  419,  418,  417,  415,  414,  413,  412,
      411,  410,  409,  408,  407,  406,  405,  404,  401,  400,
      399,  398,  397,  396,  395,  394,  393,  392,  391,  390,
      389,  388,  387,  386,  384,  383,  382,  381,  380,  379,
      378,  377,  376,  375,  374,  371,  370,  366,  362,  361,
      360,  357,  356,  355,  354,  353,  352,  351,  350,  349,
      347,  346,  345,  344,  343,  342,  341,  339,  337,  336,
      334,  333,  331,  329,  328,  327,  326,  325,  324,  323,
      321,  319,  318,  317,  316,  314,  313,  312,  311,  310,
      309,  308,  307,  306,  305,  304,  303,  302,  301,  300,

      299,  298,  297,  296,  295,  291,  290,  289,  288,  287,
      286,  285,  283,  282,  281,  280,  278,  276,  275,  270,
      269,  268,  267,  266,  265,  264,  263,  262,  260,  258,
      257,  256,  255,  253,  252,  251,  249,  248,  247,  244,
      243,  242,  241,  240,  239,  232,  231,  230,  229,  228,
      226,  225,  224,  222,  220,  219,  218,  216,  214,  213,
      211,  210,  208,  207,  204,  203,  202,  201,  200,  199,
      198,  197,  196,  193,  192,  191,  189,  188,  185,  184,
      183,  181,  180,  179,  178,  175,  174,  173,  172,  171,
      170,  169,  166,  164,  162,  161,  160,  158,  155,  154,

      153,  152,  151,  149,  148,  146,  145,  144,  143,  142,
      140,  139,  136,  135,  134,  131,  130,  129,  128,  127,
      120,  106,   99,   92,   91,   84,   79,   70,   69,   67,
       66,   65,   64,   54,   50,   49,   43,   41,   40,   33,
       22,   14,   13,    9, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,

     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041, 1041,
     1041, 1041, 1041, 1041, 1041
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "./swf5compiler.flex"
#line 2 "./swf5compiler.flex"

#include <math.h>
#include <string.h>
#include <stdlib.h>

#include "compile.h"
#include "actiontypes.h"
#include "blocks/error.h"
#include "swf5compiler.tab.h" /* defines token types */

int swf5debug;

static const char *lexBuffer = NULL;
static int lexBufferLen = 0;

static int  sLineNumber = 0, realLine = 0;
static char msgbufs[2][1024] = { {0}, {0} }, *msgline = {0};
static int  column = 0, realColumn = 0, lastToken = 0;

static void comment();
static void comment1();
static void count();
static void countline();
static void warning(char *msg);
static int yy_first_time = 1;
static int yy_new_state;

#define YY_INPUT(buf,result,max_size) result=lexBufferInput(buf, max_size)
#define YY_NO_UNISTD_H
#define YY_USE_PROTOS

/* thanks to the prolific and brilliant Raff: */
static int lexBufferInput(char *buf, int max_size)
{
  int l = lexBufferLen > max_size ? max_size : lexBufferLen;

  if (lexBufferLen <= 0)
    return YY_NULL;

  memcpy(buf, lexBuffer, l);
  lexBuffer += l;
  lexBufferLen -= l;
  return l;
}

static void unescape(char *buf)
{
  char *r, *w;

  r=buf; // read
  w=buf; // write
  while (*r)
  {
	if ( *r == '\\' )
	{
		r++;
		switch(*r)
		{
			case 'b' : *w = '\b'; break;
			case 'f' : *w = '\f'; break;
			case 'n' : *w = '\n'; break;
			case 'r' : *w = '\r'; break;
			case 't' : *w = '\t'; break;
			case 'x' :
			case 'u' : fprintf(stderr,"unsupported escape sequence\n");
				break;
			default : *w = *r; break;
		}
		w++;
		r++;
	}
	else
	{
		*w++ = *r++;
	}
  }
  *w='\0';
}

void swf5ParseInit(const char *script, int debug, int version)
{
  yyrestart(NULL);

  swf5debug = debug;

  lexBuffer = script;
  lexBufferLen = strlen(script);
  sLineNumber = 0;
  column = 0;
  msgline = msgbufs[0];
  swfVersion = version;
}

int read_int (const char *text, YYSTYPE *num)
{
  unsigned long i;

  i = strtoul (text, NULL, 0);
  if (i > 0x7FFFFFFF) {
    /* note: this catches ERANGE, too */
    num->doubleVal = atof(yytext);
    return DOUBLE;
  }
  num->intVal = i;
  return INTEGER;
}

#line 1446 "lex.swf5.c"

#line 118 "./swf5compiler.flex"
 // forward declaration needed by the following function
#ifndef YY_PROTO
#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif
#endif
 static void yyunput YY_PROTO(( int c, char *buf_ptr ));

 void do_unput5(const char c) { unput(c); }
#line 1460 "lex.swf5.c"
#line 1461 "lex.swf5.c"

#define INITIAL 0
#define STATE_ASM 1
#define STATE_LEGACY 2
#define STATE_PURE 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state ( int _new_state );
    
    static void yy_pop_state ( void );
    
    static int yy_top_state ( void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 137 "./swf5compiler.flex"



#line 141 "./swf5compiler.flex"
if (yy_first_time) {
	/* start in legacy state */
	yy_push_state(STATE_LEGACY);
	yy_first_time = 0;
	
	/* suppress unused warning for static declared function */
	yy_top_state();
}


#line 1706 "lex.swf5.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1042 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1041 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 152 "./swf5compiler.flex"
{ count(); return read_int (yytext, &swf5lval); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 153 "./swf5compiler.flex"
{ count(); return read_int (yytext, &swf5lval); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 154 "./swf5compiler.flex"
{ count(); return read_int (yytext, &swf5lval); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 155 "./swf5compiler.flex"
{ count(); swf5lval.doubleVal = atof(yytext);
				return DOUBLE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 157 "./swf5compiler.flex"
{ count(); swf5lval.doubleVal = atof(yytext);
				return DOUBLE;	}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 159 "./swf5compiler.flex"
{ count();swf5lval.intVal = 1;
				return BOOLEAN;	}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 161 "./swf5compiler.flex"
{ count(); swf5lval.intVal = 0;
				return BOOLEAN;	}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 163 "./swf5compiler.flex"
{ count();	return NULLVAL;		}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 164 "./swf5compiler.flex"
{ count();	return UNDEFINED;	}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 165 "./swf5compiler.flex"
{ count();	return TYPEOF; }
	YY_BREAK


case 11:
YY_RULE_SETUP
#line 169 "./swf5compiler.flex"
{ count();	return BREAK;		}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 170 "./swf5compiler.flex"
{ count();	return CONTINUE;	}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 171 "./swf5compiler.flex"
{ count();	return FUNCTION;	}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 172 "./swf5compiler.flex"
{ count();	return ELSE;		}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 173 "./swf5compiler.flex"
{ count();	return SWITCH;		}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 174 "./swf5compiler.flex"
{ count();	return CASE;		}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 175 "./swf5compiler.flex"
{ count();	return DEFAULT;		}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 176 "./swf5compiler.flex"
{ count();	return FOR;		}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 177 "./swf5compiler.flex"
{ count();	return IN;		}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 178 "./swf5compiler.flex"
{ count();	return IF;		}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 179 "./swf5compiler.flex"
{ count();	return WHILE;		}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 180 "./swf5compiler.flex"
{ count();	return DO;		}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 181 "./swf5compiler.flex"
{ count();	return VAR;		}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 182 "./swf5compiler.flex"
{ count();	return NEW;		}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 183 "./swf5compiler.flex"
{ count();	return DELETE;		}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 184 "./swf5compiler.flex"
{ count();	return TARGETPATH;	}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 185 "./swf5compiler.flex"
{ count();	return RETURN;		}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 186 "./swf5compiler.flex"
{ count(); 	return THIS;		}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 187 "./swf5compiler.flex"
{ count();
			  /* do not lex legacy functions in with-blocks */
			  yy_push_state(STATE_PURE);
			  yy_new_state = 1;	
			  return WITH;		
			}
	YY_BREAK
/* switch state to ASM */
case 30:
YY_RULE_SETUP
#line 195 "./swf5compiler.flex"
{ count();	
				yy_push_state(STATE_ASM); 
				yy_new_state = 1;	
				return ASM;
			}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 201 "./swf5compiler.flex"
{ count();	return EVAL;		}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 202 "./swf5compiler.flex"
{ count();	return INSTANCEOF; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 203 "./swf5compiler.flex"
{ count();	return TRACE;	}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 204 "./swf5compiler.flex"
{ count();	return CLASS; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 205 "./swf5compiler.flex"
{ count();	return EXTENDS; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 206 "./swf5compiler.flex"
{ count();	return PUBLIC; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 207 "./swf5compiler.flex"
{ count();	return PRIVATE; }
	YY_BREAK
/* SWF >= 6: lex always as reserved word complain later */
case 38:
YY_RULE_SETUP
#line 210 "./swf5compiler.flex"
{ count(); 	return TRY; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 211 "./swf5compiler.flex"
{ count(); 	return CATCH; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 212 "./swf5compiler.flex"
{ count(); 	return THROW; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 213 "./swf5compiler.flex"
{ count(); 	return FINALLY; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 214 "./swf5compiler.flex"
{ count(); 	return EEQ; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 215 "./swf5compiler.flex"
{ count(); 	return NEE; }
	YY_BREAK

/* legacy functions */
/* in some blocks legacy function names should not be lexed (e.g. with) */

case 44:
YY_RULE_SETUP
#line 221 "./swf5compiler.flex"
{ count();	return RANDOM;	}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 222 "./swf5compiler.flex"
{ count();	return GETTIMER;	}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 223 "./swf5compiler.flex"
{ count();	return LENGTH;	}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 224 "./swf5compiler.flex"
{ count();	return CONCAT;	}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 225 "./swf5compiler.flex"
{ count();	return SUBSTR;	}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 226 "./swf5compiler.flex"
{ count();	return INT;	}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 227 "./swf5compiler.flex"
{ count();	return ORD;	}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 228 "./swf5compiler.flex"
{ count();	return CHR;	}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 229 "./swf5compiler.flex"
{ count();	return GETURL;	}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 230 "./swf5compiler.flex"
{ count();	return GETURL1;	}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 231 "./swf5compiler.flex"
{ count();	return NEXTFRAME;	}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 232 "./swf5compiler.flex"
{ count();	return PREVFRAME;	}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 233 "./swf5compiler.flex"
{ count();	return PLAY;		}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 234 "./swf5compiler.flex"
{ count();	return STOP;		}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 235 "./swf5compiler.flex"
{ count();	return TOGGLEQUALITY;	}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 236 "./swf5compiler.flex"
{ count();	return STOPSOUNDS;	}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 237 "./swf5compiler.flex"
{ count();	return CALLFRAME;	}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 238 "./swf5compiler.flex"
{ count();	return GOTOANDPLAY;	}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 239 "./swf5compiler.flex"
{ count();	return GOTOANDSTOP;	}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 240 "./swf5compiler.flex"
{ count();	return SETTARGET;	}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 241 "./swf5compiler.flex"
{ count();	return LOADVARIABLES;	}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 242 "./swf5compiler.flex"
{ count();	return LOADMOVIE;	}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 243 "./swf5compiler.flex"
{ count();	return LOADVARIABLESNUM;	}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 244 "./swf5compiler.flex"
{ count();	return LOADMOVIENUM;	}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 245 "./swf5compiler.flex"
{ count();	return DUPLICATEMOVIECLIP; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 246 "./swf5compiler.flex"
{ count();	return REMOVEMOVIECLIP; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 247 "./swf5compiler.flex"
{ count();	return STARTDRAG;	}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 248 "./swf5compiler.flex"
{ count();	return STOPDRAG;	}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 249 "./swf5compiler.flex"
{ count();	return SETPROPERTY;	}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 250 "./swf5compiler.flex"
{ count();	return GETPROPERTY;	}
	YY_BREAK
/* properties (legacy) */
case 74:
YY_RULE_SETUP
#line 253 "./swf5compiler.flex"
{ count();	return _P_X; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 254 "./swf5compiler.flex"
{ count();	return _P_Y; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 255 "./swf5compiler.flex"
{ count();	return _P_XSCALE; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 256 "./swf5compiler.flex"
{ count();	return _P_YSCALE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 257 "./swf5compiler.flex"
{ count();	return _P_CURRENTFRAME; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 258 "./swf5compiler.flex"
{ count();	return _P_TOTALFRAMES; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 259 "./swf5compiler.flex"
{ count();	return _P_ALPHA; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 260 "./swf5compiler.flex"
{ count();	return _P_VISIBLE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 261 "./swf5compiler.flex"
{ count();	return _P_WIDTH; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 262 "./swf5compiler.flex"
{ count();	return _P_HEIGHT; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 263 "./swf5compiler.flex"
{ count();	return _P_ROTATION; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 264 "./swf5compiler.flex"
{ count();	return _P_TARGET; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 265 "./swf5compiler.flex"
{ count();	return _P_FRAMESLOADED; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 266 "./swf5compiler.flex"
{ count();	return _P_NAME;	}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 267 "./swf5compiler.flex"
{ count();	return _P_DROPTARGET; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 268 "./swf5compiler.flex"
{ count();	return _P_URL; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 269 "./swf5compiler.flex"
{ count();	return _P_HIGHQUALITY; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 270 "./swf5compiler.flex"
{ count();	return _P_FOCUSRECT; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 271 "./swf5compiler.flex"
{ count();	return _P_SOUNDBUFTIME; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 272 "./swf5compiler.flex"
{ count();	return _P_QUALITY; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 273 "./swf5compiler.flex"
{ count();	return _P_XMOUSE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 274 "./swf5compiler.flex"
{ count();	return _P_YMOUSE; }
	YY_BREAK

/* assembler ops */

case 96:
YY_RULE_SETUP
#line 279 "./swf5compiler.flex"
{ count();	return NEW;		}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 280 "./swf5compiler.flex"
{ count();	return DUP; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 281 "./swf5compiler.flex"
{ count();	return SWAP; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 282 "./swf5compiler.flex"
{ count();	return POP; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 283 "./swf5compiler.flex"
{ count();	return PUSH; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 284 "./swf5compiler.flex"
{ count();	return SETREGISTER; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 285 "./swf5compiler.flex"
{ count();	return CALLFUNCTION; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 286 "./swf5compiler.flex"
{ count();	return CALLMETHOD; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 287 "./swf5compiler.flex"
{ count();	return NEWOBJECT; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 288 "./swf5compiler.flex"
{ count();	return NEWMETHOD; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 289 "./swf5compiler.flex"
{ count();	return AND; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 290 "./swf5compiler.flex"
{ count();	return OR; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 291 "./swf5compiler.flex"
{ count();	return XOR; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 292 "./swf5compiler.flex"
{ count();	return MODULO; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 293 "./swf5compiler.flex"
{ count();	return ADD; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 294 "./swf5compiler.flex"
{ count();	return ADD; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 295 "./swf5compiler.flex"
{ count();	return LESSTHAN; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 296 "./swf5compiler.flex"
{ count();	return LESSTHAN; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 297 "./swf5compiler.flex"
{ count();	return EQUALS; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 298 "./swf5compiler.flex"
{ count();	return EQUALS; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 299 "./swf5compiler.flex"
{ count();	return INC; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 300 "./swf5compiler.flex"
{ count();	return DEC; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 301 "./swf5compiler.flex"
{ count();	return ENUMERATE; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 302 "./swf5compiler.flex"
{ count();	return ENUMERATE2; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 303 "./swf5compiler.flex"
{ count();	return INITOBJECT; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 304 "./swf5compiler.flex"
{ count();	return INITARRAY; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 305 "./swf5compiler.flex"
{ count();	return GETMEMBER; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 306 "./swf5compiler.flex"
{ count();	return SETMEMBER; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 307 "./swf5compiler.flex"
{ count();	return SHIFTLEFT; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 308 "./swf5compiler.flex"
{ count();	return SHIFTRIGHT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 309 "./swf5compiler.flex"
{ count();	return SHIFTRIGHT2; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 310 "./swf5compiler.flex"
{ count();	return VAREQUALS; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 311 "./swf5compiler.flex"
{ count();	return OLDADD; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 312 "./swf5compiler.flex"
{ count();	return SUBTRACT; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 313 "./swf5compiler.flex"
{ count();	return MULTIPLY; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 314 "./swf5compiler.flex"
{ count();	return DIVIDE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 315 "./swf5compiler.flex"
{ count();	return OLDEQUALS; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 316 "./swf5compiler.flex"
{ count();	return OLDLESSTHAN; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 317 "./swf5compiler.flex"
{ count();	return LOGICALAND; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 318 "./swf5compiler.flex"
{ count();	return LOGICALOR; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 319 "./swf5compiler.flex"
{ count();	return NOT; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 320 "./swf5compiler.flex"
{ count();	return STRINGEQ; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 321 "./swf5compiler.flex"
{ count();	return STRINGLENGTH; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 322 "./swf5compiler.flex"
{ count();	return SUBSTRING; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 323 "./swf5compiler.flex"
{ count();	return GETPROPERTY; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 324 "./swf5compiler.flex"
{ count();	return SETPROPERTY; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 325 "./swf5compiler.flex"
{ count();	return GETVARIABLE; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 326 "./swf5compiler.flex"
{ count();	return SETVARIABLE; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 327 "./swf5compiler.flex"
{ count();	return SETTARGETEXPRESSION; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 328 "./swf5compiler.flex"
{ count();	return STARTDRAG; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 329 "./swf5compiler.flex"
{ count();	return STOPDRAG; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 330 "./swf5compiler.flex"
{ count();	return STRINGLESSTHAN; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 331 "./swf5compiler.flex"
{ count();	return MBLENGTH; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 332 "./swf5compiler.flex"
{ count();	return MBSUBSTRING; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 333 "./swf5compiler.flex"
{ count();	return MBORD; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 334 "./swf5compiler.flex"
{ count();	return MBCHR; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 335 "./swf5compiler.flex"
{ count();	return BRANCHALWAYS; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 336 "./swf5compiler.flex"
{ count();	return BRANCHALWAYS; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 337 "./swf5compiler.flex"
{ count();	return BRANCHIFTRUE; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 338 "./swf5compiler.flex"
{ count();	return POST; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 339 "./swf5compiler.flex"
{ count();	return GET; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 340 "./swf5compiler.flex"
{ count();	return END;		}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 341 "./swf5compiler.flex"
{ count();	return EXTENDS;		}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 342 "./swf5compiler.flex"
{ count();	return TONUMBER;	}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 343 "./swf5compiler.flex"
{ count();	return TOSTRING;	}
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 344 "./swf5compiler.flex"
{ count();	return TARGETPATH;	}
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 345 "./swf5compiler.flex"
{ count();	return DUPLICATEMOVIECLIP; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 346 "./swf5compiler.flex"
{ count();	return REMOVEMOVIECLIP; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 347 "./swf5compiler.flex"
{ count(); 	return IMPLEMENTS;	}
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 348 "./swf5compiler.flex"
{ count(); 	return FSCOMMAND2;	}
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 349 "./swf5compiler.flex"
{ count();	return CAST;		}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 350 "./swf5compiler.flex"
{ count(); swf5lval.str = strdup(yytext+2);
				return REGISTER; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 352 "./swf5compiler.flex"
{ count();	return TRACE;	}
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 353 "./swf5compiler.flex"
{ count();	return DELETE;		}
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 354 "./swf5compiler.flex"
{ count();	return DELETE2;		}
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 355 "./swf5compiler.flex"
{ count();	return SWFACTION;	}
	YY_BREAK

/* rules action in any state */

case 172:
YY_RULE_SETUP
#line 360 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup(yytext);
					return IDENTIFIER;	}
	YY_BREAK
case 173:
/* rule 173 can match eol */
YY_RULE_SETUP
#line 363 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup(yytext+1);
					swf5lval.str[strlen(swf5lval.str)-1]=0;
                                        unescape(swf5lval.str);
					return STRING;		}
	YY_BREAK
case 174:
/* rule 174 can match eol */
YY_RULE_SETUP
#line 368 "./swf5compiler.flex"
{ count();	swf5lval.str = strdup(yytext+1);
					swf5lval.str[strlen(swf5lval.str)-1]=0;
                                        unescape(swf5lval.str);
					return STRING; 		}
	YY_BREAK
case 175:
/* rule 175 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 373 "./swf5compiler.flex"
{ count();	swf5lval.str = NULL;
					warning("Unterminated string!");
					return BROKENSTRING;		}
	YY_BREAK
case 176:
/* rule 176 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 377 "./swf5compiler.flex"
{ count();	swf5lval.str = NULL;
					warning("Unterminated string!");
					return BROKENSTRING;		}
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 381 "./swf5compiler.flex"
{ count();	comment();		}
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 382 "./swf5compiler.flex"
{ count();	comment1();		}
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 383 "./swf5compiler.flex"
{ count(); }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 385 "./swf5compiler.flex"
{ count();	return INCR; }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 386 "./swf5compiler.flex"
{ count();	return DECR; }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 387 "./swf5compiler.flex"
{ count();	return LE; }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 388 "./swf5compiler.flex"
{ count();	return GE; }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 389 "./swf5compiler.flex"
{ count();	return EQ; }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 390 "./swf5compiler.flex"
{ count();	return NE; }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 391 "./swf5compiler.flex"
{ count();	return LAN; }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 392 "./swf5compiler.flex"
{ count();	return LOR; }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 393 "./swf5compiler.flex"
{ count();	return MEQ; }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 394 "./swf5compiler.flex"
{ count();	return DEQ; }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 395 "./swf5compiler.flex"
{ count();	return IEQ; }
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 396 "./swf5compiler.flex"
{ count();	return SEQ; }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 397 "./swf5compiler.flex"
{ count();	return AEQ; }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 398 "./swf5compiler.flex"
{ count();	return OEQ; }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 399 "./swf5compiler.flex"
{ count();	return SHL; }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 400 "./swf5compiler.flex"
{ count();	return SHR; }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 401 "./swf5compiler.flex"
{ count();	return SHR2; }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 402 "./swf5compiler.flex"
{ count();	return SHLEQ; }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 403 "./swf5compiler.flex"
{ count();	return SHREQ; }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 404 "./swf5compiler.flex"
{ count();	return SHR2EQ; }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 406 "./swf5compiler.flex"
{ count();	return '<'; }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 407 "./swf5compiler.flex"
{ count();	return '>'; }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 408 "./swf5compiler.flex"
{ count();	return ';'; }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 409 "./swf5compiler.flex"
{ count();	return '='; }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 410 "./swf5compiler.flex"
{ count();	return '+'; }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 411 "./swf5compiler.flex"
{ count();	return '-'; }
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 412 "./swf5compiler.flex"
{ count();	return '&'; }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 413 "./swf5compiler.flex"
{ count();	return '|'; }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 414 "./swf5compiler.flex"
{ count();	return '^'; }
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 415 "./swf5compiler.flex"
{ count();	return '*'; }
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 416 "./swf5compiler.flex"
{ count();	return '/'; }
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 417 "./swf5compiler.flex"
{ count();	return '%'; }
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 418 "./swf5compiler.flex"
{ count();	return '!'; }
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 419 "./swf5compiler.flex"
{ count();	return '('; }
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 420 "./swf5compiler.flex"
{ count();	return ')'; }
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 421 "./swf5compiler.flex"
{ count();	return '['; }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 422 "./swf5compiler.flex"
{ count();	return ']'; }
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 424 "./swf5compiler.flex"
{ count();	
			  if(yy_new_state)
			  {
				// if yy_new_state state was already pushed
				// and will be poped by closing '}'
				yy_new_state = 0;
			  }
			  else
			  {
				// push current state on top of stack
				// preserves state when closing '}' pops stack
			  	yy_push_state(YY_START); 
			  }
			  return '{'; 
			}
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 440 "./swf5compiler.flex"
{ count();	
			  yy_pop_state(); 
			  return '}'; 
			}
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 445 "./swf5compiler.flex"
{ count();	return ','; }
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 446 "./swf5compiler.flex"
{ count();	return '.'; }
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 447 "./swf5compiler.flex"
{ count();	return '?'; }
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 448 "./swf5compiler.flex"
{ count();	return ':'; }
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 449 "./swf5compiler.flex"
{ count();	return '~'; }
	YY_BREAK
case 224:
/* rule 224 can match eol */
YY_RULE_SETUP
#line 451 "./swf5compiler.flex"
{ countline();	yyless(1);	}
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 453 "./swf5compiler.flex"
SWF_error("Unrecognized character: %s\n", yytext);
	YY_BREAK

case 226:
YY_RULE_SETUP
#line 456 "./swf5compiler.flex"
ECHO;
	YY_BREAK
#line 2960 "lex.swf5.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(STATE_ASM):
case YY_STATE_EOF(STATE_LEGACY):
case YY_STATE_EOF(STATE_PURE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1042 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1042 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1041);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 456 "./swf5compiler.flex"

static int getinput() {
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
}

int swf5wrap()
{
  return 1;
}

static void countline()
{
  ++sLineNumber;
  column = 0;
  msgline = msgbufs[sLineNumber & 1];
}

static int LineNumber(void)
{
   return realLine + 1;
}

static int ColumnNumber(void)
{
   return realColumn;
}

static char *LineText(void)
{
  return msgbufs[realLine & 1];
}

static void comment()
{
   // Handle block comments

   int c, c1;

loop:
   // We have the start of a comment so look skip everything up to the
   // end of the comment character
   while ((c = getinput()) != '*' && c != EOF)
   {
      if(column < 1023)
         msgline[column] = c;

      ++column;

      // keep the line number in synch
      if (c == '\n')
      {
         // start the output (matches the algorithim in the lexx above)
	 countline();
      }

      if (swf5debug) putchar(c);
   }

   // is this the end of comment character
   if ((c1 = getinput()) != '/' && c != EOF)
   {
      // false start as this was no end of comment
      do_unput5(c1);
      goto loop;
   }

   // write out the start of the end of comment
   if (c != EOF)
      if (swf5debug) putchar(c);

   // write out the end of the end of comment
   if (c1 != EOF) 
      if (swf5debug) putchar(c1);
}

static void comment1()
{
   // Handle comment of type 1 (ie '//')

   int c;

   // this is a line comment
   while ((c = getinput()) != '\n' && c != EOF)
   {
      if (swf5debug) putchar(c);

      if(column < 1023)
         msgline[column] = c;

      ++column;
   };

   // keep the line number in synch
   if (c == '\n')
   {
      if (swf5debug) putchar(c);

      countline();
   }
}

static void count(void)
{
   int n;

   if(swf5debug) printf("%s", yytext);
   if(realLine != sLineNumber)
   {
     if(column > 0 || realLine + 1 < sLineNumber)
     {
       realColumn = 0;
       realLine = sLineNumber;
     }
   }
   realColumn += lastToken;
   lastToken = 0;
   for(n=0; n<yyleng; ++n, ++column, ++lastToken)
   {
     if(column < 1023)
       msgline[column] = yytext[n];
   }
   if(column < 1023)
     msgline[column] = 0;
   else
     msgline[1023] = 0;
}

static void printprog()
{
  if(sLineNumber)
    SWF_warn("\n%s", msgbufs[(sLineNumber-1)&1]);

  if(column < 1023)
    msgline[column] = 0;

  SWF_warn("\n%s", msgline);
}

static void warning(char *msg)
{
   // print a warning message
   printprog();
   SWF_warn("\n%*s", ColumnNumber(), "^");
   SWF_warn("\nLine %4.4d:  Reason: '%s' \n", LineNumber(), msg);
}

void swf5error(char *msg)
{
  // report a error
  if(strlen(yytext))
  {
    SWF_error("\n%s\n%*s\nLine %i:  Reason: '%s'\n",
	      LineText(), ColumnNumber(), "^", LineNumber(), msg);
  }
  else
  {
    SWF_error("\nLine %d: Reason: 'Unexpected EOF found while looking for input.'\n", LineNumber());
  }
}

